package main

import (
	"log"

	"git.javil.eu/jacob1123/budgeteer/bcrypt"
	"git.javil.eu/jacob1123/budgeteer/config"
	"git.javil.eu/jacob1123/budgeteer/http"
	"git.javil.eu/jacob1123/budgeteer/jwt"
	"git.javil.eu/jacob1123/budgeteer/postgres"
)

func main() {
	cfg, err := config.LoadConfig()
	if err != nil {
		log.Fatalf("Could not load config: %v", err)
	}

	q, err := postgres.Connect("pgx", cfg.DatabaseConnection)
	if err != nil {
		log.Fatalf("Failed connecting to DB: %v", err)
	}

	h := &http.Handler{
		Service:             q,
		TokenVerifier:       &jwt.TokenVerifier{},
		CredentialsVerifier: &bcrypt.Verifier{},
	}

	h.Serve()
}
